=======
History
=======

0.2.2
------------------

* Bugfixes.

0.2
------------------

* Various updates under the hood, frequencies of localization tags added to final report.

0.1.4
------------------

* Clustering algorithm, console script and readme update.


0.1.3
------------------

* Readme and dependencies update.


0.1.2
------------------

* Various improvements and fixes.


0.1.0 (2021-02-11)
------------------

* First release on PyPI.
